@@ -2,4 +2,5 @@ from .workspace import init, clean
 from .split import split
 from .entities import annotate
 from .relations import relate
-from .save import save_all, save_entities, save_relations
+from .save import save_entities, save_relations
+from .how_to import print_help
