@@ -9,9 +9,8 @@ from ..utils.filesystem import load_data, \
 def split() -> None:
     config = load_config()
 
-    split_config = config['split'] if 'split' in config else {}
-    seed = split_config['seed'] if 'seed' in split_config else None
-    partition_point = split_config['amount'] if 'amount' in split_config else 25
+    seed = config['split']['seed']
+    split_point = config['split']['amount']
 
     source_data = load_data(
         os.path.join(WORKSPACE, '1', config['source'])
@@ -22,7 +21,7 @@ def split() -> None:
 
     random.shuffle(source_data)
 
-    pivot = int(len(source_data) * partition_point) if partition_point < 1 else partition_point
+    pivot = int(len(source_data) * split_point) if split_point < 1 else split_point
     development_set, holdout_set = (source_data[:pivot], source_data[pivot:])
 
     output_directory = os.path.join(WORKSPACE, '2')
